@@ -8,6 +8,8 @@ BEGIN { eval "use Mail::Internet;";
     eval "use Test::Differences";
 }
 
+package Email::Abstract::Mail;
+use base 'Email::Abstract::MailInternet';
 # keep a sequence number so we can order things later
 package Mail;
 use base 'Mail::Internet';
@@ -47,6 +49,7 @@ sub dump_into {
                          sort { eval { $a->topmost->message->order } <=>
                                 eval { $b->topmost->message->order } } @_;
                      });
+
     $_->iterate_down(
         sub {
             my ($self, $level) = @_;
